@@ -123,7 +123,7 @@ class GoogleTestFacade(AbstractFacade):
 
             results = self._parse_xml(xml_filename)
 
-        for (executed_test_id, failures, skipped) in results:
+        for executed_test_id, failures, skipped in results:
             if executed_test_id == test_id:
                 if failures:
                     return [GoogleTestFailure(x) for x in failures], output
