@@ -1,9 +1,9 @@
 import subprocess
 import sys
 import tempfile
+from shutil import which
 
 import pytest
-from distutils.spawn import find_executable
 
 from pytest_cpp import error
 from pytest_cpp.boost import BoostTestFacade
@@ -62,6 +62,11 @@ def dummy_failure():
             "catch2_success",
             ["Factorials are computed", "Passed Sections"],
         ),
+        (
+            Catch2Facade(),
+            "catch2_success_v3",
+            ["Factorials are computed", "Passed Sections"],
+        ),
     ],
 )
 def test_list_tests(facade, name, expected, exes):
@@ -446,7 +451,7 @@ def test_argument_option_priority(testdir, exes):
 
 
 @pytest.mark.skipif(
-    not find_executable("valgrind") or not find_executable("catchsegv"),
+    not which("valgrind") or not which("catchsegv"),
     reason="Environment does not have required tools",
 )
 def test_google_cpp_harness_via_option(testdir, exes):
@@ -499,7 +504,7 @@ def test_boost_two_arguments_via_option(testdir, exes):
 
 
 @pytest.mark.skipif(
-    not find_executable("valgrind") or not find_executable("catchsegv"),
+    not which("valgrind") or not which("catchsegv"),
     reason="Environment does not have required tools",
 )
 def test_boost_cpp_harness_via_option(testdir, exes):
@@ -596,26 +601,56 @@ def test_cpp_verbose(testdir, exes):
     )
 
 
+def assert_catch2_failure(line, expected_line, expected_colors):
+    assert expected_line in line[0]
+    assert line[1] == expected_colors
+
+
 def test_catch2_failure(exes):
+    for suffix in ["", "_v3"]:
+        facade = Catch2Facade()
+        failures, _ = facade.run_test(
+            exes.get(f"catch2_failure{suffix}"), "Factorials are computed"
+        )
+        assert len(failures) == 1
+
+        fail1 = failures[0]
+        colors = ("red", "bold")
+        assert_catch2_failure(fail1.get_lines()[0], "Expected: ", colors)
+        assert_catch2_failure(fail1.get_lines()[1], "Factorial(1) == 0", colors)
+        assert_catch2_failure(fail1.get_lines()[3], "Actual: ", colors)
+        assert_catch2_failure(fail1.get_lines()[4], "1 == 0", colors)
+
+        assert fail1.get_file_reference() == (f"catch2_failure.cpp", 9)
+
+        failures, _ = facade.run_test(
+            exes.get(f"catch2_failure{suffix}"), "Failed Sections"
+        )
+        assert len(failures) == 2
+
+        # test exceptions
+        failures, _ = facade.run_test(exes.get(f"catch2_error{suffix}"), "Error")
+        [fail1] = failures
+        assert_catch2_failure(fail1.get_lines()[0], "Error: ", colors)
+        assert_catch2_failure(fail1.get_lines()[1], "a runtime error", colors)
+
+
+@pytest.mark.parametrize("suffix", ["", "_v3"])
+@pytest.mark.parametrize(
+    "test_id",
+    [
+        "Brackets in [test] name",
+        "**Star in test name**",
+        "~Tilde in test name",
+        "Comma, in, test, name",
+        r"Backslash\ in\ test\ name",
+        '"Quotes" in test name',
+    ],
+)
+def test_catch2_special_chars(suffix, test_id, exes):
     facade = Catch2Facade()
-    failures, _ = facade.run_test(exes.get("catch2_failure"), "Factorials are computed")
-    assert len(failures) == 1
-
-    fail1 = failures[0]
-    colors = ("red", "bold")
-    assert fail1.get_lines() == [
-        ("Expected: ", colors),
-        ("          Factorial(1) == 0", colors),
-        ("        ", colors),
-        ("Actual: ", colors),
-        ("          1 == 0", colors),
-        ("        ", colors),
-    ]
-
-    assert fail1.get_file_reference() == ("catch2_failure.cpp", 9)
-
-    failures, _ = facade.run_test(exes.get("catch2_failure"), "Failed Sections")
-    assert len(failures) == 2
+    exe = exes.get("catch2_special_chars" + suffix)
+    assert facade.run_test(exe, test_id)[0] is None
 
 
 class TestError:
